#include <hidef.h>				// common defines and macros */
#include "derivative.h"			// derivative-specific definitions */


void DIP_SW_TEST(void);
void ATD_EN(void);
void ATD_TEST(void);
void LED_TEST(byte dir);

#define ATDCH	0x08				// select ATD ch
#define SW2		PTP_PTP3
#define SW3		PTP_PTP2
#define SW4		PTP_PTP1
#define SW5		PTP_PTP0
#define PBSW	PTP |= 0xF0		// PBSW status in PTP low nibble
#define DPSW1	PORTB_PB7
#define DPSW2 	PORTB_PB6
#define DPSW3	PORTB_PB5
#define DPSW4	PORTB_PB4
#define DPSW5	PORTB_PB3
#define DPSW6	PORTB_PB2
#define DPSW7	PORTB_PB1
#define DPSW8	PORTB_PB0
#define DPSW	PORTB
#define LED1	PORTA_PA0		// LED1 assigned to D9
#define LED2	PORTA_PA1	
#define LED3	PORTA_PA2	
#define LED4	PORTA_PA3	
#define LED5	PORTA_PA4	
#define LED6	PORTA_PA5	
#define LED7	PORTA_PA6	
#define LED8	PORTA_PA7		// LED8 assigned to D2
#define LEDS	PORTA

void main(void) {
	word sw_stat;
	
	DisableInterrupts;
	PORTA = 0xFF;					// init porta, all leds off 
	DDRA = 0xFF;					// porta output
	PTP = 0xFF;						// init portp	
	DDRP = 0xF0;					// ptp[3:0] input
	PERP = 0x0F;					// enable pulls
	PPSP = 0x00;					// pull-downs
	PIFP = 0xFF;					// clr spurious flags
	PORTB = 0x0;					// init PORTB
	DDRB = 0x0;						// PORTB input
	PUCR_PUPBE = 1;				// PORTB pull enable
	
	REFDV = 0x40;					// XTAL=4MHz
	ATD_EN();
   sw_stat = 0;					// init temp var

	for(;;){
 		if (PIFP){
			sw_stat=PTP |= 0xF0;	// get SW input and mask hi nibble
			PIFP = 0xFF;			// clear int flag
		}
		
		switch(sw_stat){
			case 0xF7: 				// SW2 pressed
				DIP_SW_TEST();
				break;
			case 0xFB: 				// SW3 pressed
				ATD_TEST();
				break;
			case 0xFD:
				LED_TEST(1);
				break;
			case 0xFE:
				LED_TEST(0);
				break;
			default:
				break;
		}
	}
}


// LED marching pattern
void LED_TEST(byte dir){
	
	byte n;
	word m;
	
	if (dir){
		PORTA = 0xFE;					// init PORT A
		for(n=0;n<8;n++){
			for(m=0;m<0xFFFF;m++);	// wait
			PORTA = PORTA << 1;				// shift LED bit
		}
	}else {
		PORTA = 0x7F;					// init PORT A
		for(n=0;n<8;n++){
			for(m=0;m<0xFFFF;m++);	// wait
			PORTA = PORTA >> 1;		// shift LED bit
		}
	}
	PORTA = 0xFF;					// LEDs OFF
}


// DIP SW Test
void DIP_SW_TEST(void){

	LEDS = DPSW;						// display DPSW setting on LEDs
}


// init ATD
void ATD_EN(void){

	ATD0CTL1_SRES = 0;				// 8 bit results
	ATD0CTL3_DJM = 1;					// right justified data
	ATD0CTL4_PRS = 0;					// bus clk div 2, 4 clks per sample
	ATD0STAT0_SCF = 1;				// clear flag
}


// read ATD & set LEDs
void ATD_TEST(void){
	byte atd_val, stat;
	
	ATD0CTL5_Cx = ATDCH;				// start conversion on selected CH
	while(!(ATD0STAT0_SCF));		// wait for conversion complete
	atd_val = (byte) ATD0DR0;		// get converted value
	if(atd_val <= 0x3C){
		stat = 1;						// temp status value
	} else if ((atd_val > 0x3C) && (atd_val <= 0x78)) {
		stat = 2;
	} else if ((atd_val > 0x78) && (atd_val <= 0xB4)){
		stat = 3;
	} else if ((atd_val > 0xB4) && (atd_val <= 0xF0)){
		stat = 4;
	} else if (atd_val > 0xF0){
		stat = 5;
	}
	switch(stat){
		case 1: 
			LEDS = 0x00;				// all LEDs ON
			break;
		case 2:
			LEDS = 0xC0;
			break;
		case 3:
			LEDS = 0xF0;
			break;
		case 4:
			LEDS = 0xFC;
			break;
		case 5:
			LEDS = 0xFF;				// all LEDs OFF
			break;
		default:
			break;
	}
	
}

















